#
# spec file for package CCfits
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   2_6
Name:           CCfits
Version:        2.7
Release:        1.1
Summary:        An object oriented interface to the cfitsio library
License:        MIT
Group:          System/Libraries
URL:            https://heasarc.gsfc.nasa.gov/docs/software/fitsio/ccfits/
Source0:        https://heasarc.gsfc.nasa.gov/FTP/software/fitsio/ccfits/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM CCfits-cmake-install-pkgconfig.patch badshah400@gmail.com -- Configure and install pkgconfig file when building using cmake
Patch0:         CCfits-cmake-install-pkgconfig.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cfitsio)

%description
It is designed to make the capabilities of cfitsio available to programmers
working in C++. It is written in ANSI C++ and implemented using the C++
Standard Library with namespaces, exception handling, and member template
functions.

%package -n     lib%{name}%{sover}
Summary:        An object oriented interface to the cfitsio library
Group:          System/Libraries

%description -n lib%{name}%{sover}
It is designed to make the capabilities of cfitsio available to programmers
working in C++. It is written in ANSI C++ and implemented using the C++
Standard Library with namespaces, exception handling, and member template
functions.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{sover} = %{version}
Requires:       pkgconfig(cfitsio)

%description    devel
An object oriented interface to the cfitsio library.

This package contains header files, and libraries needed to develop
application that use %{name}.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%cmake -DTESTS:BOOL=ON
%cmake_build

%install
%cmake_install

%check
%ctest

%ldconfig_scriptlets -n lib%{name}%{sover}

%files -n lib%{name}%{sover}
%doc CHANGES
%license License*
%{_libdir}/lib%{name}.so.*

%files devel
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Tue Apr 22 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.7:
  * New function HDU::addKeyNull() for creating keywords with null
    values (ie. CFITSIO's fits_write_key_null() functionality).
    Existing keywords with null values can now also be modified.
- Build using cmake.
- Run tests in the %%check section.
- Add CCfits-cmake-install-pkgconfig.patch: configure and install
  pkgconfig file when using cmake for build; patch emailed
  upstream since no proper upstream issue tracker exists.
- Drop patches no longer needed (due to switching to cmake):
  * CCfits-2.5-removerpath.patch
  * cfitsio-path.patch
* Sun Dec 11 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2.6:
  See included CHANGES file for details.
* Wed Jan 20 2021 Paolo Stivanin <info@paolostivanin.com>
- Add cfitsio-path.patch: this patch fixes an import error that prevents
  a successfull compilation, because it's currently importing headers
  from a non-existing location
- Add CCfits-2.5-removerpath.patch: this patch removes rpath in the
  shared library compile instruction
* Sat Jan  4 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2.5:
  * As part of an effort to allow tables to hold multiple columns
    with the same name (see "Enhancements" section), the Table
    class now stores Column objects in an internal multimap
    rather than a map. This affects the public interface in 2
    places: the ExtHDU::column() and Table::column() accessor
    functions. These used to return a std::map reference, but now
    return a std::multimap (using new typedef 'ColMap' defined in
    CCfits.h).
  * Removed the ImageExt<T>::image() accessor function from the
    public interface. This was only ever intended for internal use.
  * Enhancements:
  - Added scripts for building with the CMake system, primarily
    intended for builds on Windows platforms.
  - New functions: ExtHDU::copyColumn, HDU::readNextKey,
    HDU::resetImageRead, and a new Column::read overload for
    returning a single row into a std::vector.
  - Keyword reads can now convert numerical types into strings.
  - Added support for variable-width string columns (with new
    ValueType enum = VTstring).
  - Image write functions are now allowed to dynamically
    increase the size of the outer dimension as needed. The
    corresponding NAXIS keyword will be updated automatically.
  - Tables can now handle having multiple columns with the same
    column name. (Also see "Backwards Compatibility" section.)
  - Added support for read/write of LONGLONG types for images.
  - Added handling of 'D' exponent notation when reading keyword
    values with floating-point types.
  * Bug Fixes:
  - Improved memory caching when reading images, reducing the
    number of unnecessary disk reads.
  - Removed header inclusion of config.h due to potential
    conflicts with users' customized autotools config.h files.
  - HDU's '<<' output operator was not showing output for the
    highest numbered axis.
  - Removed unused NewColumn.h code file.
  - Fixed memory leak in internal Column::setLimits function.
  - Added #include statements to various files, the absence of
    which was causing compilation failures on recent Windows
    Visual Studio builds.
  - Added missing 'break' statement for Tlonglong case in
    internal FITSType2String function.
  - Replaced a valarray operation in ColumnVectorData.h file
    which caused a compiler glitch on certain Mac platforms.
    (This was previously released as a patch.)
  - Fix made to HDU's getHistory and getComments internal search
    algorithm.
  - Fix to FITS::addTable function for case where new table
    shares its name with a pre-existing HDU but has a different
    version number.
  - Fix to memory management for certain Column write
    operations.
* Fri Oct 16 2015 avvissu@yandex.ru
- Initial release
